@@ -115,6 +115,53 @@ describe 'tripleo::haproxy' do
       end
     end
 
+    describe "default Defaults for haproxy" do
+      it 'should NOT activate httplog' do
+        is_expected.to contain_class('haproxy').with(
+          :defaults_options => {
+            "mode"=>"tcp",
+            "log"=>"global",
+            "retries"=>"3",
+            "timeout"=> [
+              "http-request 10s",
+              "queue 2m",
+              "connect 10s",
+              "client 2m",
+              "server 2m",
+              "check 10s",
+            ],
+            "maxconn"=>4096,
+          }
+        )
+      end
+    end
+
+    describe "activate httplog" do
+      before :each do
+        params.merge!({
+          :activate_httplog => true,
+        })
+      end
+      it 'should activate httplog' do
+        is_expected.to contain_class('haproxy').with(
+          :defaults_options => {
+            "mode"=>"tcp",
+            "log"=>"global",
+            "retries"=>"3",
+            "timeout"=> [
+              "http-request 10s",
+              "queue 2m",
+              "connect 10s",
+              "client 2m",
+              "server 2m",
+              "check 10s",
+            ],
+            "maxconn"=>4096,
+            "option"=>"httplog",
+          }
+        )
+      end
+    end
   end
 
   on_supported_os.each do |os, facts|
@@ -127,4 +174,4 @@ describe 'tripleo::haproxy' do
     end
   end
 
-end
\ No newline at end of file
+end
